sqlobject.inheritance.tests package — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests package

## Submodules

- sqlobject.inheritance.tests.test_aggregates module
- sqlobject.inheritance.tests.test_asdict module
- sqlobject.inheritance.tests.test_deep_inheritance module
- sqlobject.inheritance.tests.test_destroy_cascade module
- sqlobject.inheritance.tests.test_foreignKey module
- sqlobject.inheritance.tests.test_indexes module
- sqlobject.inheritance.tests.test_inheritance module
- sqlobject.inheritance.tests.test_inheritance_tree module